/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of ENC demo for the TOSHIBA 'TMPM372'
 *          Device Series
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
#include "main.h"
volatile uint32_t g_flag;
volatile uint32_t enccount = 15U;

/**
  * @brief  Delay 10ms
  * @param  None
  * @retval None
  */
void Delay1(void)
{
    uint32_t TimeCounter;
    uint32_t DelayTime = 50000U;
    for (TimeCounter = 0U; TimeCounter < DelayTime; TimeCounter++) {
        /* Do nothing */
    }
}
/**
  * @brief  Delay time
  * @param  time
  * @retval None
  */
void Delay2(uint32_t time)
{
    uint32_t count;
    for (count = 0U; count < time; count++){
        Delay1();
    }
}

/**
  * @brief  Main function
  * @param  None
  * @retval None
  */
int main(void)
{
    ENC_InitTypeDef m_enc;
    ENC_FlagStatus f_enc;
    
    /* LED initialization */
    LED_Init();

    /* ENC1 initialization */   
    m_enc.ModeType = ENC_ENCODER_MODE;
    m_enc.PhaseType = ENC_TWO_PHASE;
    m_enc.CompareStatus = ENC_COMPARE_DISABLE;
    m_enc.ZphaseStatus = ENC_ZPHASE_DISABLE;
    m_enc.FilterValue = ENC_FILTER_VALUE31;
    m_enc.IntEn = ENC_INTERRUPT_ENABLE;
    m_enc.PulseDivFactor = ENC_PULSE_DIV1;
    
    ENC_Init(EN1,&m_enc);
    ENC_SetCounterReload(EN1,0xFFFU);
    
    /* GPIO initialization */
    GPIO_SetInputEnableReg(GPIO_PF, GPIO_BIT_2, ENABLE);      /* Set PF2 as input */
    GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_2); /* Set PF2 as ENCA1 */
    GPIO_SetInputEnableReg(GPIO_PF, GPIO_BIT_3, ENABLE);      /* Set PF3 as input */
    GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_3); /* Set PF3 as ENCB1 */
    
    /* Enable ENC1 */
    ENC_Enable(EN1);
    /* Enable ENC1 interrupt */
    NVIC_EnableIRQ(INTENC1_IRQn);   
    
    /* LED1 blink speed based on the rolling of mouse wheel */
    while(1){
        f_enc = ENC_GetENCFlag(EN1);
        g_flag = f_enc.Bit.RotationDirection;  
        LED_On(LED1);
        Delay2(enccount);
        LED_Off(LED1);
        Delay2(enccount);
    } 
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
