/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of UART_Retarget demo for the TOSHIBA
 *          'TMPM372' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  main  function
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t TSW_info;
    uint8_t wait_TSW1 = 1U;
    char TxBuffer[] = "TMPM37x";

    /* Initialize system */
    SW_Init();
    SIO_Configuration(UART_RETARGET);
    SIO_ChInit();

    /* enable retarget Channel TRX interrupt */
    NVIC_EnableIRQ(RETARGET_INT);
    while (1) {
        while (wait_TSW1) {
            /* read Key SW1 input */
            TSW_info = SW_Get(TSW_PORT);
            if (TSW_info == 1) {
                /* wait for Key SW1 released */
                do {
                    wait_TSW1 = 0U;
                    TSW_info = SW_Get(TSW_PORT);
                } while (TSW_info != TSWRELEASE);
            }
        }

        printf("%s\r\n", TxBuffer);     /* SIO0 send data */

        while (fSIOTxOK == NO) {        /* wait for UART_RETARGET finish send */
            /* do nothing */
        }
        fSIOTxOK = NO;
        wait_TSW1 = 1U;
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
